@@ -307,7 +307,6 @@ GstNetTimeProvider *  gst_rtsp_media_get_time_provider (GstRTSPMedia *media,
 GST_RTSP_SERVER_API
 void                  gst_rtsp_media_set_clock         (GstRTSPMedia *media, GstClock * clock);
 
-
 GST_RTSP_SERVER_API
 void                    gst_rtsp_media_set_publish_clock_mode (GstRTSPMedia * media, GstRTSPPublishClockMode mode);
 
@@ -325,6 +324,11 @@ void                  gst_rtsp_media_set_bind_mcast_address  (GstRTSPMedia *medi
 GST_RTSP_SERVER_API
 gboolean              gst_rtsp_media_is_bind_mcast_address  (GstRTSPMedia *media);
 
+GST_RTSP_SERVER_API
+void                  gst_rtsp_media_set_dscp_qos (GstRTSPMedia * media, gint dscp_qos);
+GST_RTSP_SERVER_API
+gint                  gst_rtsp_media_get_dscp_qos (GstRTSPMedia * media);
+
 /* prepare the media for playback */
 
 GST_RTSP_SERVER_API
@@ -364,6 +368,12 @@ GstRTSPStream *       gst_rtsp_media_create_stream    (GstRTSPMedia *media,
 
 /* dealing with the media */
 
+GST_RTSP_SERVER_API
+void                  gst_rtsp_media_lock             (GstRTSPMedia *media);
+
+GST_RTSP_SERVER_API
+void                  gst_rtsp_media_unlock           (GstRTSPMedia *media);
+
 GST_RTSP_SERVER_API
 GstClock *            gst_rtsp_media_get_clock        (GstRTSPMedia *media);
 
@@ -387,6 +397,13 @@ gboolean              gst_rtsp_media_seek_full        (GstRTSPMedia *media,
                                                        GstRTSPTimeRange *range,
                                                        GstSeekFlags flags);
 
+GST_RTSP_SERVER_API
+gboolean              gst_rtsp_media_seek_trickmode   (GstRTSPMedia *media,
+                                                       GstRTSPTimeRange *range,
+                                                       GstSeekFlags flags,
+                                                       gdouble rate,
+                                                       GstClockTime trickmode_interval);
+
 GST_RTSP_SERVER_API
 GstClockTimeDiff      gst_rtsp_media_seekable         (GstRTSPMedia *media);
 
@@ -395,6 +412,11 @@ gchar *               gst_rtsp_media_get_range_string (GstRTSPMedia *media,
                                                        gboolean play,
                                                        GstRTSPRangeUnit unit);
 
+GST_RTSP_SERVER_API
+gboolean              gst_rtsp_media_get_rates        (GstRTSPMedia * media,
+                                                       gdouble * rate,
+                                                       gdouble * applied_rate);
+
 GST_RTSP_SERVER_API
 gboolean              gst_rtsp_media_set_state        (GstRTSPMedia *media, GstState state,
                                                        GPtrArray *transports);
@@ -406,6 +428,18 @@ void                  gst_rtsp_media_set_pipeline_state (GstRTSPMedia * media,
 GST_RTSP_SERVER_API
 gboolean              gst_rtsp_media_complete_pipeline (GstRTSPMedia * media, GPtrArray * transports);
 
+GST_RTSP_SERVER_API
+gboolean              gst_rtsp_media_is_receive_only (GstRTSPMedia * media);
+
+GST_RTSP_SERVER_API
+gboolean              gst_rtsp_media_has_completed_sender (GstRTSPMedia * media);
+
+GST_RTSP_SERVER_API
+void                  gst_rtsp_media_set_rate_control (GstRTSPMedia * media, gboolean enabled);
+
+GST_RTSP_SERVER_API
+gboolean              gst_rtsp_media_get_rate_control (GstRTSPMedia * media);
+
 #ifdef G_DEFINE_AUTOPTR_CLEANUP_FUNC
 G_DEFINE_AUTOPTR_CLEANUP_FUNC(GstRTSPMedia, gst_object_unref)
 #endif
